==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/bn.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'bn', {
	button: {
		title: 'বাটন প্রোপার্টি',
		text: 'টেক্সট (ভ্যালু)',
		type: 'প্রকার',
		typeBtn: 'Button',
		typeSbm: 'Submit',
		typeRst: 'Reset'
	},
	checkboxAndRadio: {
		checkboxTitle: 'চেক বক্স প্রোপার্টি',
		radioTitle: 'রেডিও বাটন প্রোপার্টি',
		value: 'ভ্যালু',
		selected: 'সিলেক্টেড'
	},
	form: {
		title: 'ফর্ম প্রোপার্টি',
		menu: 'ফর্ম প্রোপার্টি',
		action: 'একশ্যন',
		method: 'পদ্ধতি',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'গুপ্ত ফীল্ড প্রোপার্টি',
		name: 'নাম',
		value: 'ভ্যালু'
	},
	select: {
		title: 'বাছাই ফীল্ড প্রোপার্টি',
		selectInfo: 'তথ্য',
		opAvail: 'অন্যান্য বিকল্প',
		value: 'ভ্যালু',
		size: 'সাইজ',
		lines: 'লাইন সমূহ',
		chkMulti: 'একাধিক সিলেকশন এলাউ কর',
		opText: 'টেক্সট',
		opValue: 'ভ্যালু',
		btnAdd: 'যুক্ত',
		btnModify: 'বদলে দাও',
		btnUp: 'উপর',
		btnDown: 'নীচে',
		btnSetValue: 'বাছাই করা ভ্যালু হিসেবে সেট কর',
		btnDelete: 'ডিলীট'
	},
	textarea: {
		title: 'টেক্সট এরিয়া প্রোপার্টি',
		cols: 'কলাম',
		rows: 'রো'
	},
	textfield: {
		title: 'টেক্সট ফীল্ড প্রোপার্টি',
		name: 'নাম',
		value: 'ভ্যালু',
		charWidth: 'ক্যারেক্টার প্রশস্ততা',
		maxChars: 'সর্বাধিক ক্যারেক্টার',
		type: 'টাইপ',
		typeText: 'টেক্সট',
		typePass: 'পাসওয়ার্ড',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/bn.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'bn', {
	button: {
		title: 'বাটন প্রোপার্টি',
		text: 'টেক্সট (ভ্যালু)',
		type: 'প্রকার',
		typeBtn: 'Button',
		typeSbm: 'Submit',
		typeRst: 'Reset'
	},
	checkboxAndRadio: {
		checkboxTitle: 'চেক বক্স প্রোপার্টি',
		radioTitle: 'রেডিও বাটন প্রোপার্টি',
		value: 'ভ্যালু',
		selected: 'সিলেক্টেড',
		required: 'Required' // MISSING
	},
	form: {
		title: 'ফর্ম প্রোপার্টি',
		menu: 'ফর্ম প্রোপার্টি',
		action: 'একশ্যন',
		method: 'পদ্ধতি',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'গুপ্ত ফীল্ড প্রোপার্টি',
		name: 'নাম',
		value: 'ভ্যালু'
	},
	select: {
		title: 'বাছাই ফীল্ড প্রোপার্টি',
		selectInfo: 'তথ্য',
		opAvail: 'অন্যান্য বিকল্প',
		value: 'ভ্যালু',
		size: 'সাইজ',
		lines: 'লাইন সমূহ',
		chkMulti: 'একাধিক সিলেকশন এলাউ কর',
		required: 'Required', // MISSING
		opText: 'টেক্সট',
		opValue: 'ভ্যালু',
		btnAdd: 'যুক্ত',
		btnModify: 'বদলে দাও',
		btnUp: 'উপর',
		btnDown: 'নীচে',
		btnSetValue: 'বাছাই করা ভ্যালু হিসেবে সেট কর',
		btnDelete: 'ডিলীট'
	},
	textarea: {
		title: 'টেক্সট এরিয়া প্রোপার্টি',
		cols: 'কলাম',
		rows: 'রো'
	},
	textfield: {
		title: 'টেক্সট ফীল্ড প্রোপার্টি',
		name: 'নাম',
		value: 'ভ্যালু',
		charWidth: 'ক্যারেক্টার প্রশস্ততা',
		maxChars: 'সর্বাধিক ক্যারেক্টার',
		required: 'Required', // MISSING
		type: 'টাইপ',
		typeText: 'টেক্সট',
		typePass: 'পাসওয়ার্ড',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'URL'
	}
} );
